@@ -7,7 +7,7 @@ require Carp;
 require Scalar::Util;
 use File::Spec ();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 our $LEADING_SPACE  = qr/(?:\n [ ]*)?/x;
 our $TRAILING_SPACE = qr/(?:[ ]* \n)?/x;
@@ -75,7 +75,7 @@ sub _parse {
             my $leading_newline = !!$1;
 
             # Tripple
-            if ($template =~ m/\G { (.*?) } $END_TAG/gcxms) {
+            if ($template =~ m/\G \{ (.*?) \} $END_TAG/gcxms) {
                 $chunk .= $self->_parse_tag($1, $context);
             }
 
@@ -738,9 +738,11 @@ Ovidiu Stateina
 
 Fernando Oliveira
 
+Shoichi Kaji (skaji)
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2015, Viacheslav Tykhanovskyi
+Copyright (C) 2011-2017, Viacheslav Tykhanovskyi
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
